"""
    schemas: Encoded (compiled) type messages that are applicable to compiled
    platform statuses and observations (from the platform), and compiled
    mission plans (to the platform). This encoded schema is applicable to the
    different message types: mission_plan_encoded, observation_encoded, and
    platform_status_encoded.
"""

encoded_schema = {
    "type": "object",
    "properties": {
        "message_type": {
            "type": "string",
            "description": "Type of message",
            "example": "mission_plan",
            "enum": [
                "mission_plan_encoded",
                "observation_encoded",
                "platform_status_encoded",
            ],
        },
        "data": {
            "type": "string",
            "description": "encoded string. E.g. Base64 encoded",
            "example": "SDQke4uwyP/YQQAgAhA2AND/nu8nvQAAAAAAAAAACtejPa5HHUGkcB"
            + "AAAAIAAAAQAAAAAAAAAA9P2cP166ab+9cg==",
        },
        "file_name": {
            "type": "string",
            "description": "Name of file",
            "example": "ah1-0238126349247372.bin",
        },
        "mime_type": {
            "type": "string",
            "description": "MIME type",
            "example": "application/gzip",
        },
        "is_binary": {
            "type": "boolean",
            "description": (
                "True if the data field contains binary format data encoded as base64."
                + " False if the data field contains ascii content such as NMEA."
            ),
            "example": True,
        },
    },
    "required": ["data", "is_binary"],
}
